#!/bin/sh
#
# Build Debian modules for TechnoTrend Premium DVB S2-6400
# The build directory needs at least 1 GByte space!
#
URL=https://github.com/s-moch/linux-saa716x/compare
FWLOADER=http://www.aregel.de/file_download/7/dvb-ttpremium-loader-01_v1_03.zip
FPGAFW=http://www.aregel.de/file_download/26/dvb-ttpremium-fpga-01_v1_10.zip
FIRMWARE=http://www.aregel.de/file_download/28/dvb-ttpremium-st7109-01_v0_5_1.zip
BUILDDIR=/tmp/linux-saa716x
KERNELVERSION=$(uname -r)
KMAJOR=$(echo $KERNELVERSION | cut -d'.' -f1)
KMINOR=$(echo $KERNELVERSION | cut -d'.' -f2)
DIFF=saa716x-$KMAJOR.$KMINOR.diff
DESTINATION=/lib/modules/$KERNELVERSION/kernel
PACKAGES="fakeroot build-essential devscripts libncurses5 libncurses5-dev bison flex libssl-dev wget libelf-dev unzip linux-source-$KMAJOR.$KMINOR linux-headers-$KERNELVERSION"

if [ $KMAJOR -gt 4 ]; then
    # Bullseye
    SECTION=drivers/media/pci/saa716x
else
    # Buster
    SECTION=drivers/media/common/saa716x
fi

finish() {
    if [ $? = 0 ]; then
#	rm -rf $BUILDDIR/linux-source-$KMAJOR.$KMINOR $BUILDDIR/*.zip
#	tar -czf /tmp/linux-saa716x.tar.gz $BUILDDIR
	echo "## SUCCESS"
    else
	echo "## FAILED"
    fi
    rm -rf $BUILDDIR
}

[ x$(whoami) = xroot ] || exit 1

apt-get install $PACKAGES || exit 1
trap finish exit

rm -rf $BUILDDIR
mkdir -p $BUILDDIR || exit 1
cd $BUILDDIR || exit 1

wget $URL/$DIFF || exit 1
wget $FWLOADER || exit 1
wget $FPGAFW || exit 1
wget $FIRMWARE || exit 1
unzip $(basename $FWLOADER) || exit 1
unzip $(basename $FPGAFW) || exit 1
unzip $(basename $FIRMWARE) || exit 1
cp -af *.fw /lib/firmware/ || exit 1

tar xJf /usr/src/linux-source-$KMAJOR.$KMINOR.tar.xz || exit 1
cd linux-source-$KMAJOR.$KMINOR/ || exit 1
cp /boot/config-$KERNELVERSION .config || exit 1
cp /usr/src/linux-headers-$KERNELVERSION/Module.symvers . || exit 1
patch -p1 < ../$DIFF || exit 1
printf "y\nm\nm\nm\nm\n" | make oldconfig || exit 1
make KERNELVERSION=$KERNELVERSION -j6 modules_prepare || exit 1
make KERNELVERSION=$KERNELVERSION -j6 M=$SECTION modules || exit 1
[ -e $DESTINATION/$SECTION ] || mkdir -p $DESTINATION/$SECTION || exit 1
cp -f $SECTION/*.ko $DESTINATION/$SECTION/ || exit 1
depmod $KERNELVERSION || exit 1
grep -sq saa716x /proc/modules || modprobe saa716x_ff || exit 1
